@@ -89,7 +89,7 @@ public:
     //! conjugation
     Complex conj() const;
 
-    _Tp re, im; //< the real and the imaginary parts
+    _Tp re, im; ///< the real and the imaginary parts
 };
 
 typedef Complex<float> Complexf;
@@ -475,7 +475,14 @@ public:
     template<typename _Tp2> operator Rect_<_Tp2>() const;
 
     //! checks whether the rectangle contains the point
-    bool contains(const Point_<_Tp>& pt) const;
+    /*! @warning After OpenCV 4.11.0, when calling Rect.contains() with cv::Point2f / cv::Point2d point, point should not convert/round to int.
+     * ```
+     * Rect_<int> r(0,0,500,500); Point_<float> pt(250.0f, 499.9f);
+     * r.contains(pt) returns false.(OpenCV 4.10.0 or before)
+     * r.contains(pt) returns true. (OpenCV 4.11.0 or later)
+     * ```
+     */
+    template<typename _Tp2> inline bool contains(const Point_<_Tp2>& pt) const;
 
     _Tp x; //!< x coordinate of the top-left corner
     _Tp y; //!< y coordinate of the top-left corner
@@ -527,38 +534,44 @@ The sample below demonstrates how to use RotatedRect:
 
 @sa CamShift, fitEllipse, minAreaRect, CvBox2D
 */
-class CV_EXPORTS RotatedRect
+class CV_EXPORTS_W_SIMPLE RotatedRect
 {
 public:
     //! default constructor
-    RotatedRect();
+    CV_WRAP RotatedRect();
     /** full constructor
     @param center The rectangle mass center.
     @param size Width and height of the rectangle.
     @param angle The rotation angle in a clockwise direction. When the angle is 0, 90, 180, 270 etc.,
     the rectangle becomes an up-right rectangle.
     */
-    RotatedRect(const Point2f& center, const Size2f& size, float angle);
+    CV_WRAP RotatedRect(const Point2f& center, const Size2f& size, float angle);
     /**
     Any 3 end points of the RotatedRect. They must be given in order (either clockwise or
     anticlockwise).
      */
-    RotatedRect(const Point2f& point1, const Point2f& point2, const Point2f& point3);
+    CV_WRAP RotatedRect(const Point2f& point1, const Point2f& point2, const Point2f& point3);
 
-    /** returns 4 vertices of the rectangle
-    @param pts The points array for storing rectangle vertices. The order is bottomLeft, topLeft, topRight, bottomRight.
+    /** returns 4 vertices of the rotated rectangle
+    @param pts The points array for storing rectangle vertices. The order is _bottomLeft_, _topLeft_, topRight, bottomRight.
+    @note _Bottom_, _Top_, _Left_ and _Right_ sides refer to the original rectangle (angle is 0),
+    so after 180 degree rotation _bottomLeft_ point will be located at the top right corner of the
+    rectangle.
     */
     void points(Point2f pts[]) const;
+
+    CV_WRAP void points(CV_OUT std::vector<Point2f>& pts) const;
+
     //! returns the minimal up-right integer rectangle containing the rotated rectangle
-    Rect boundingRect() const;
+    CV_WRAP Rect boundingRect() const;
     //! returns the minimal (exact) floating point rectangle containing the rotated rectangle, not intended for use with images
-    Rect_<float> boundingRect2f() const;
+    CV_WRAP Rect2f boundingRect2f() const;
     //! returns the rectangle mass center
-    Point2f center;
+    CV_PROP_RW Point2f center;
     //! returns width and height of the rectangle
-    Size2f size;
+    CV_PROP_RW Size2f size;
     //! returns the rotation angle. When the angle is 0, 90, 180, 270 etc., the rectangle becomes an up-right rectangle.
-    float angle;
+    CV_PROP_RW float angle;
 };
 
 template<> class DataType< RotatedRect >
@@ -1855,12 +1868,29 @@ Rect_<_Tp>::operator Rect_<_Tp2>() const
     return Rect_<_Tp2>(saturate_cast<_Tp2>(x), saturate_cast<_Tp2>(y), saturate_cast<_Tp2>(width), saturate_cast<_Tp2>(height));
 }
 
-template<typename _Tp> inline
-bool Rect_<_Tp>::contains(const Point_<_Tp>& pt) const
+template<typename _Tp> template<typename _Tp2> inline
+bool Rect_<_Tp>::contains(const Point_<_Tp2>& pt) const
 {
     return x <= pt.x && pt.x < x + width && y <= pt.y && pt.y < y + height;
 }
-
+// See https://github.com/opencv/opencv/issues/26016
+template<> template<> inline
+bool Rect_<int>::contains(const Point_<double>& pt) const
+{
+    // std::numeric_limits<int>::digits is 31.
+    // std::numeric_limits<double>::digits is 53.
+    // So conversion int->double does not lead to accuracy errors.
+    const Rect_<double> _rect(static_cast<double>(x), static_cast<double>(y), static_cast<double>(width), static_cast<double>(height));
+    return _rect.contains(pt);
+}
+template<> template<> inline
+bool Rect_<int>::contains(const Point_<float>& _pt) const
+{
+    // std::numeric_limits<float>::digits is 24.
+    // std::numeric_limits<double>::digits is 53.
+    // So conversion float->double does not lead to accuracy errors.
+    return contains(Point_<double>(static_cast<double>(_pt.x), static_cast<double>(_pt.y)));
+}
 
 template<typename _Tp> static inline
 Rect_<_Tp>& operator += ( Rect_<_Tp>& a, const Point_<_Tp>& b )
@@ -2025,8 +2055,8 @@ double jaccardDistance(const Rect_<_Tp>& a, const Rect_<_Tp>& b) {
 /** @brief Finds out if there is any intersection between two rectangles
  *
  * mainly useful for language bindings
- * @param rect1 First rectangle
- * @param rect2 Second rectangle
+ * @param a First rectangle
+ * @param b Second rectangle
  * @return the area of the intersection
  */
 CV_EXPORTS_W inline double rectangleIntersectionArea(const Rect2d& a, const Rect2d& b) { return (a & b).area(); }
